@@ -6,8 +6,6 @@ use warnings;
 use base 'Devel::Chitin';
 use IO::File;
 
-our $VERSION = '0.23_15';
-
 sub new {
     my($class, $file, $cb) = @_;
 
@@ -131,8 +129,7 @@ sub notify_trace {
     my $at_subname  = $at_location->subroutine;
 
     # The expected next location
-    chomp(my $next_trace_line = $self->_next_trace_line);
-    my($exp_location, $exp_package, $exp_file, $exp_line, $exp_subname) = split("\t", $next_trace_line);
+    my($exp_location, $exp_package, $exp_file, $exp_line, $exp_subname) = split("\t", $self->_next_trace_line);
 
     my $should_stop;
     if (my ($expected_sub, $expected_offset) = $exp_location =~ m/(.*)\+(\d+)$/) {
@@ -150,7 +147,7 @@ sub notify_trace {
     }
 
     if ($should_stop) {
-        my($package) = $at_subname =~ m/(.*)::(\w+)$/;
+        my($package) = $at_subname = ~ m/(.*)::(\w+)$/;
         $package ||= 'main';
         my %diff_data = (
                 'package'   => $package,
